@@ -63,62 +63,64 @@ print.MplusRstructure <- function(x, ...) {
 #' unlink("Mplus Run Models.log")
 #' }
 summary.mplusObject <- function(object, verbose=FALSE, ...) {
-  stopifnot(isFALSE(is.null(object$results)))
-
-  x <- object$results$summaries
-
-  if(isFALSE(verbose)) {
-
-    cat(gsub("(.*)(;)", "\\1 \n\n", x$Title))
-    cat(sprintf("Estimated using %s \n", x$Estimator))
-
-    cat(sprintf("Number of obs: %s, number of (free) parameters: %s \n\n",
-      x$Observations, x$Parameters))
-
-    if(!is.null(x[["ChiSqM_DF"]])){
-      cat(with(x, sprintf("Model: Chi2(df = %s) = %s, p = %s \n",
-                          ChiSqM_DF, ChiSqM_Value, ChiSqM_PValue)))
+  if(isTRUE(is.null(object[["results"]]))){
+    cat("mplusObject with elements:\n  ", paste0(names(object), collapse = ", "))
+  } else {
+    x <- object$results$summaries
+    
+    if(isFALSE(verbose)) {
+      
+      cat(gsub("(.*)(;)", "\\1 \n\n", x$Title))
+      cat(sprintf("Estimated using %s \n", x$Estimator))
+      
+      cat(sprintf("Number of obs: %s, number of (free) parameters: %s \n\n",
+                  x$Observations, x$Parameters))
+      
+      if(!is.null(x[["ChiSqM_DF"]])){
+        cat(with(x, sprintf("Model: Chi2(df = %s) = %s, p = %s \n",
+                            ChiSqM_DF, ChiSqM_Value, ChiSqM_PValue)))
+      }
+      if(!is.null(x[["ChiSqBaseline_DF"]])){
+        cat(with(x, sprintf("Baseline model: Chi2(df = %s) = %s, p = %s \n\n",
+                            ChiSqBaseline_DF, ChiSqBaseline_Value, ChiSqBaseline_PValue)))
+      }
+      if(is.null(x[["CFI"]])){
+        x[["CFI"]] <- NA
+      }
+      if(is.null(x[["TLI"]])){
+        x[["TLI"]] <- NA
+      }
+      if(is.null(x[["SRMR"]])){
+        x[["SRMR"]] <- NA
+      }
+      cat("Fit Indices: \n\n")
+      cat(with(x, sprintf("CFI = %s, TLI = %s, SRMR = %s \n", CFI, TLI, SRMR)))
+      if(is.null(x[["RMSEA_Estimate"]])){
+        x[["RMSEA_Estimate"]] <- NA
+      }
+      if(is.null(x[["RMSEA_90CI_LB"]])){
+        x[["RMSEA_90CI_LB"]] <- NA
+      }
+      if(is.null(x[["RMSEA_90CI_UB"]])){
+        x[["RMSEA_90CI_UB"]] <- NA
+      }
+      if(is.null(x[["RMSEA_pLT05"]])){
+        x[["RMSEA_pLT05"]] <- NA
+      }
+      cat(with(x, sprintf("RMSEA = %s, 90%% CI [%s, %s], p < .05 = %s \n",
+                          RMSEA_Estimate, RMSEA_90CI_LB, RMSEA_90CI_UB, RMSEA_pLT05)))
+      if(is.null(x[["AIC"]])){
+        x[["AIC"]] <- NA
+      }
+      if(is.null(x[["BIC"]])){
+        x[["BIC"]] <- NA
+      }
+      cat(with(x, sprintf("AIC = %s, BIC = %s \n", AIC, BIC)))
+    } else if(isTRUE(verbose)) {
+      invisible(lapply(names(x), function(n) {
+        cat(sprintf("%s: %s \n", n, x[[n]]))
+      }))
     }
-    if(!is.null(x[["ChiSqBaseline_DF"]])){
-    cat(with(x, sprintf("Baseline model: Chi2(df = %s) = %s, p = %s \n\n",
-      ChiSqBaseline_DF, ChiSqBaseline_Value, ChiSqBaseline_PValue)))
-    }
-    if(is.null(x[["CFI"]])){
-      x[["CFI"]] <- NA
-    }
-    if(is.null(x[["TLI"]])){
-      x[["TLI"]] <- NA
-    }
-    if(is.null(x[["SRMR"]])){
-      x[["SRMR"]] <- NA
-    }
-    cat("Fit Indices: \n\n")
-    cat(with(x, sprintf("CFI = %s, TLI = %s, SRMR = %s \n", CFI, TLI, SRMR)))
-    if(is.null(x[["RMSEA_Estimate"]])){
-      x[["RMSEA_Estimate"]] <- NA
-    }
-    if(is.null(x[["RMSEA_90CI_LB"]])){
-      x[["RMSEA_90CI_LB"]] <- NA
-    }
-    if(is.null(x[["RMSEA_90CI_UB"]])){
-      x[["RMSEA_90CI_UB"]] <- NA
-    }
-    if(is.null(x[["RMSEA_pLT05"]])){
-      x[["RMSEA_pLT05"]] <- NA
-    }
-    cat(with(x, sprintf("RMSEA = %s, 90%% CI [%s, %s], p < .05 = %s \n",
-      RMSEA_Estimate, RMSEA_90CI_LB, RMSEA_90CI_UB, RMSEA_pLT05)))
-    if(is.null(x[["AIC"]])){
-      x[["AIC"]] <- NA
-    }
-    if(is.null(x[["BIC"]])){
-      x[["BIC"]] <- NA
-    }
-    cat(with(x, sprintf("AIC = %s, BIC = %s \n", AIC, BIC)))
-  } else if(isTRUE(verbose)) {
-    invisible(lapply(names(x), function(n) {
-      cat(sprintf("%s: %s \n", n, x[[n]]))
-    }))
   }
 }
 
@@ -128,6 +130,12 @@ print.mplusObject <- function(x, ...){
   print(summary(x))
 }
 
+#' @method print mixture.list
+#' @export
+print.mixture.list <- function(x, ...){
+  print(mixtureSummaryTable(x))
+}
+
 #' @method print mplus.model
 #' @export
 print.mplus.model <- print.mplusObject
